==> ui-18.1.3.tgz: package/components/accordion/Accordion.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isNull, nth } from 'lodash';
import { useId } from '@react-devui/hooks';
import { DownOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_BASE } from '../../utils';
import { DCollapseTransition } from '../_transition';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DAccordion' });
export function DAccordion(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dList, dActive, dActiveOne = false, dArrow = 'right', onActiveChange, afterActiveChange } = _a, restProps = __rest(_a, ["dList", "dActive", "dActiveOne", "dArrow", "onActiveChange", "afterActiveChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const uniqueId = useId();
    const getButtonId = (id) => `${dPrefix}accordion-button-${id}-${uniqueId}`;
    const getRegionId = (id) => `${dPrefix}accordion-region-${id}-${uniqueId}`;
    const [activeId, changeActiveId] = useDValue(dActiveOne ? null : [], dActive, (id) => {
        if (onActiveChange) {
            if (dActiveOne) {
                onActiveChange(id, isNull(id) ? null : dList.find((a) => a.id === id));
            }
            else {
                let length = id.length;
                const items = [];
                const reduceArr = (arr) => {
                    for (const item of arr) {
                        if (length === 0) {
                            break;
                        }
                        const index = id.findIndex((v) => v === item.id);
                        if (index !== -1) {
                            items[index] = item;
                            length -= 1;
                        }
                    }
                };
                reduceArr(dList);
                onActiveChange(id, items);
            }
        }
    });
    return (_jsx("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}accordion`) }, { children: dList.map((item, index) => {
            const { id: itemId, title: itemTitle, region: itemRegion, arrow: itemArrow = dArrow, disabled: itemDisabled = false } = item;
            const getAccordion = (next, _index = index) => {
                for (let focusIndex = next ? _index + 1 : _index - 1, n = 0; n < dList.length; next ? focusIndex++ : focusIndex--, n++) {
                    const t = nth(dList, focusIndex % dList.length);
                    if (t && !t.disabled) {
                        return t;
                    }
                }
            };
            const focusTab = (t) => {
                if (t) {
                    const el = document.getElementById(getButtonId(t.id));
                    if (el) {
                        el.focus();
                    }
                }
            };
            const buttonId = getButtonId(itemId);
            const regionId = getRegionId(itemId);
            const isActive = dActiveOne ? activeId === itemId : activeId.includes(itemId);
            const iconRotate = (() => {
                if (itemArrow === 'left' && !isActive) {
                    return -90;
                }
                if (itemArrow === 'right' && isActive) {
                    return 180;
                }
                return undefined;
            })();
            const handleClick = () => {
                if (dActiveOne) {
                    changeActiveId(isActive ? null : itemId);
                }
                else {
                    changeActiveId((draft) => {
                        const index = draft.findIndex((v) => v === itemId);
                        if (index !== -1) {
                            draft.splice(index, 1);
                        }
                        else {
                            draft.push(itemId);
                        }
                    });
                }
            };
            return (_jsxs("div", Object.assign({ className: getClassName(`${dPrefix}accordion__item`, {
                    [`${dPrefix}accordion__item--last`]: index === dList.length - 1,
                }) }, { children: [_jsxs("div", Object.assign({ id: buttonId, className: getClassName(`${dPrefix}accordion__item-button`, {
                            [`${dPrefix}accordion__item-button--arrow-left`]: itemArrow === 'left',
                            'is-disabled': itemDisabled,
                        }), tabIndex: itemDisabled ? -1 : 0, role: "button", "aria-controls": regionId, "aria-expanded": isActive, "aria-disabled": itemDisabled, onClick: handleClick, onKeyDown: (e) => {
                            switch (e.code) {
                                case 'Enter':
                                case 'Space':
                                    e.preventDefault();
                                    handleClick();
                                    break;
                                case 'ArrowUp':
                                    e.preventDefault();
                                    focusTab(getAccordion(false));
                                    break;
                                case 'ArrowDown':
                                    e.preventDefault();
                                    focusTab(getAccordion(true));
                                    break;
                                case 'Home':
                                    e.preventDefault();
                                    for (const a of dList) {
                                        if (!a.disabled) {
                                            focusTab(a);
                                            break;
                                        }
                                    }
                                    break;
                                case 'End':
                                    e.preventDefault();
                                    for (let index = dList.length - 1; index >= 0; index--) {
                                        if (!dList[index].disabled) {
                                            focusTab(dList[index]);
                                            break;
                                        }
                                    }
                                    break;
                                default:
                                    break;
                            }
                        } }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}accordion__item-title` }, { children: itemTitle })), itemArrow && _jsx(DownOutlined, { className: `${dPrefix}accordion__item-arrow`, dRotate: iconRotate })] })), _jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
                            height: 'auto',
                        }, dCollapsedStyle: {
                            height: 0,
                        }, dIn: isActive, dDuring: TTANSITION_DURING_BASE, dStyles: {
                            enter: { opacity: 0 },
                            entering: {
                                transition: ['height', 'padding', 'margin', 'opacity']
                                    .map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`)
                                    .join(', '),
                            },
                            leaving: {
                                opacity: 0,
                                transition: ['height', 'padding', 'margin', 'opacity']
                                    .map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`)
                                    .join(', '),
                            },
                            leaved: { display: 'none' },
                        }, afterEnter: () => {
                            afterActiveChange === null || afterActiveChange === void 0 ? void 0 : afterActiveChange(itemId, item, true);
                        }, afterLeave: () => {
                            afterActiveChange === null || afterActiveChange === void 0 ? void 0 : afterActiveChange(itemId, item, false);
                        } }, { children: (collapseRef, collapseStyle) => (_jsx("div", Object.assign({ ref: collapseRef, id: regionId, className: `${dPrefix}accordion__item-region`, style: collapseStyle, role: "region", "aria-labelledby": getButtonId(itemId) }, { children: itemRegion }))) }))] }), itemId));
        }) })));
}

==> ui-18.5.6.tgz: package/components/accordion/Accordion.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { isNull, nth } from 'lodash';
import { useId } from '@react-devui/hooks';
import { DownOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate, TTANSITION_DURING_BASE } from '../../utils';
import { DCollapseTransition } from '../_transition';
import { useComponentConfig, usePrefixConfig } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DAccordion' });
export function DAccordion(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dList, dActive, dActiveOne = false, dArrow = 'right', onActiveChange, afterActiveChange } = _a, restProps = __rest(_a, ["dList", "dActive", "dActiveOne", "dArrow", "onActiveChange", "afterActiveChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const uniqueId = useId();
    const getButtonId = (id) => `${dPrefix}accordion-button-${id}-${uniqueId}`;
    const getRegionId = (id) => `${dPrefix}accordion-region-${id}-${uniqueId}`;
    const [activeId, changeActiveId] = useDValue(dActiveOne ? null : [], dActive, (id) => {
        if (onActiveChange) {
            if (dActiveOne) {
                onActiveChange(id, isNull(id) ? null : dList.find((a) => a.id === id));
            }
            else {
                let length = id.length;
                const items = [];
                const reduceArr = (arr) => {
                    for (const item of arr) {
                        if (length === 0) {
                            break;
                        }
                        const index = id.findIndex((v) => v === item.id);
                        if (index !== -1) {
                            items[index] = item;
                            length -= 1;
                        }
                    }
                };
                reduceArr(dList);
                onActiveChange(id, items);
            }
        }
    });
    return (_jsx("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}accordion`) }, { children: dList.map((item, index) => {
            const { id: itemId, title: itemTitle, region: itemRegion, arrow: itemArrow = dArrow, disabled: itemDisabled = false } = item;
            const getAccordion = (next, _index = index) => {
                for (let focusIndex = next ? _index + 1 : _index - 1, n = 0; n < dList.length; next ? focusIndex++ : focusIndex--, n++) {
                    const t = nth(dList, focusIndex % dList.length);
                    if (t && !t.disabled) {
                        return t;
                    }
                }
            };
            const focusTab = (t) => {
                if (t) {
                    const el = document.getElementById(getButtonId(t.id));
                    if (el) {
                        el.focus();
                    }
                }
            };
            const buttonId = getButtonId(itemId);
            const regionId = getRegionId(itemId);
            const isActive = dActiveOne ? activeId === itemId : activeId.includes(itemId);
            const iconRotate = (() => {
                if (itemArrow === 'left' && !isActive) {
                    return -90;
                }
                if (itemArrow === 'right' && isActive) {
                    return 180;
                }
                return undefined;
            })();
            const handleClick = () => {
                if (dActiveOne) {
                    changeActiveId(isActive ? null : itemId);
                }
                else {
                    changeActiveId((draft) => {
                        const index = draft.findIndex((v) => v === itemId);
                        if (index !== -1) {
                            draft.splice(index, 1);
                        }
                        else {
                            draft.push(itemId);
                        }
                    });
                }
            };
            const titleNode = _jsx("div", Object.assign({ className: `${dPrefix}accordion__item-title` }, { children: itemTitle }));
            const arrowNode = itemArrow && _jsx(DownOutlined, { className: `${dPrefix}accordion__item-arrow`, dRotate: iconRotate });
            return (_jsxs("div", Object.assign({ className: getClassName(`${dPrefix}accordion__item`, {
                    [`${dPrefix}accordion__item--last`]: index === dList.length - 1,
                }) }, { children: [_jsx("div", Object.assign({ id: buttonId, className: getClassName(`${dPrefix}accordion__item-button`, {
                            'is-disabled': itemDisabled,
                        }), tabIndex: itemDisabled ? -1 : 0, role: "button", "aria-controls": regionId, "aria-expanded": isActive, "aria-disabled": itemDisabled, onClick: handleClick, onKeyDown: (e) => {
                            switch (e.code) {
                                case 'Enter':
                                case 'Space':
                                    e.preventDefault();
                                    handleClick();
                                    break;
                                case 'ArrowUp':
                                    e.preventDefault();
                                    focusTab(getAccordion(false));
                                    break;
                                case 'ArrowDown':
                                    e.preventDefault();
                                    focusTab(getAccordion(true));
                                    break;
                                case 'Home':
                                    e.preventDefault();
                                    for (const a of dList) {
                                        if (!a.disabled) {
                                            focusTab(a);
                                            break;
                                        }
                                    }
                                    break;
                                case 'End':
                                    e.preventDefault();
                                    for (let index = dList.length - 1; index >= 0; index--) {
                                        if (!dList[index].disabled) {
                                            focusTab(dList[index]);
                                            break;
                                        }
                                    }
                                    break;
                                default:
                                    break;
                            }
                        } }, { children: itemArrow === 'left' ? (_jsxs(_Fragment, { children: [arrowNode, titleNode] })) : (_jsxs(_Fragment, { children: [titleNode, arrowNode] })) })), _jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
                            height: 'auto',
                        }, dCollapsedStyle: {
                            height: 0,
                        }, dIn: isActive, dDuring: TTANSITION_DURING_BASE, dStyles: {
                            enter: { opacity: 0 },
                            entering: {
                                transition: ['height', 'padding', 'margin', 'opacity']
                                    .map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`)
                                    .join(', '),
                            },
                            leaving: {
                                opacity: 0,
                                transition: ['height', 'padding', 'margin', 'opacity']
                                    .map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`)
                                    .join(', '),
                            },
                            leaved: { display: 'none' },
                        }, afterEnter: () => {
                            afterActiveChange === null || afterActiveChange === void 0 ? void 0 : afterActiveChange(itemId, item, true);
                        }, afterLeave: () => {
                            afterActiveChange === null || afterActiveChange === void 0 ? void 0 : afterActiveChange(itemId, item, false);
                        } }, { children: (collapseRef, collapseStyle) => (_jsx("div", Object.assign({ ref: collapseRef, id: regionId, className: `${dPrefix}accordion__item-region`, style: collapseStyle, role: "region", "aria-labelledby": getButtonId(itemId) }, { children: itemRegion }))) }))] }), itemId));
        }) })));
}
